@@ -8,14 +8,14 @@ use LBMA::Statistics;
 
 my $lbma =  LBMA::Statistics->new();
 
-	# @fixings 
-	# 0 date
-	# 1 GOLD A.M. USD 
-	# 2 GOLD A.M. GBP
-	# 3 GOLD A.M. EUR
-	# 4 GOLD P.M. USD
-	# 5 GOLD P.M. GBP
-	# 6 GOLD P.M. EUR 
+
+        # @fixings 
+        # 0 date
+        # 1 Silver USD 
+        # 2 Silver GBP
+        # 3 Silver EUR
+
 print join("|",$lbma->dailysilverfixing() ) ,"\n";
+print join("|",$lbma->dailysilverfixing( year => 2009, month => 7, day => 19 ) ) , "\n";
 print join("|",$lbma->dailysilverfixing( year => 2009, month => 2, day => 2) ) , "\n";
 print join("|",$lbma->dailysilverfixing( year => 2000, month => 1, day => 4) ) , "\n";
